<?php

namespace SenSai;

use FML\Controls\Frame;
use FML\Controls\Quad;
use FML\ManiaLink;
use ManiaControl\ManiaControl;
use ManiaControl\Manialinks\ManialinkManager;
use ManiaControl\Manialinks\IconManager;
use ManiaControl\Plugins\Plugin;
use ManiaControl\Callbacks\CallbackListener;
use ManiaControl\Callbacks\Callbacks;
use ManiaControl\Players\Player;
use ManiaControl\Players\PlayerManager;


/**
 * ManiaControl Logo Plugin
 *
 * @author G]R [SG-1] Sen-Sai
 */
class LogoPlugin implements Plugin, CallbackListener {
	/**
	 * Constants
	 */
	const PLUGIN_ID				= 37;
	const PLUGIN_VERSION		= 0.92;
	const PLUGIN_NAME			= 'LogoPlugin';
	const PLUGIN_AUTHOR			= 'G]R [SG-1]Sen-sai';
	const DATE					= 'd-m-y h:i:sa T';
	const MLID_LOGO				= 'LogoPlugin.MLID';

	const SETTING_LOGO_IMG_URL 	= 'Logo URL';
	const SETTING_LOGO_URL 		= 'Goto URL';
	const SETTING_LOGO_POSX		= 'Logo-Widget-Position: X';
	const SETTING_LOGO_POSY		= 'Logo-Widget-Position: Y';	
	const SETTING_LOGO_SIZEX	= 'Logo-Widget-Size: X';
	const SETTING_LOGO_SIZEY	= 'Logo-Widget-Size: Y';



	/**
	 * Private properties
	 */
	/** @var maniaControl $maniaControl */
	private $maniaControl = null;
	private $logodetails = array();

	/**
	 * Prepares the Plugin
	 *
	 * @param ManiaControl $maniaControl
	 * @return mixed
	 */
	public static function prepare(ManiaControl $maniaControl) {
		
		
	}

	/**
	 * @see \ManiaControl\Plugins\Plugin::load()
	 */
	public function load(ManiaControl $maniaControl) {
		$this->maniaControl = $maniaControl;
			
		// Init settings
		$this->maniaControl->settingManager->initSetting($this, self::SETTING_LOGO_IMG_URL, 'http://files.designburo.nl/shootmania/images/glrimratten.png');
		$this->maniaControl->settingManager->initSetting($this, self::SETTING_LOGO_URL, 'http://designburo.nl/shootmania');
		$this->maniaControl->settingManager->initSetting($this, self::SETTING_LOGO_POSX, -148);
		$this->maniaControl->settingManager->initSetting($this, self::SETTING_LOGO_POSY	, 64);
		$this->maniaControl->settingManager->initSetting($this, self::SETTING_LOGO_SIZEX, 20);
		$this->maniaControl->settingManager->initSetting($this, self::SETTING_LOGO_SIZEY, 20);
		$this->maniaControl->callbackManager->registerCallbackListener(PlayerManager::CB_PLAYERCONNECT, $this, 'handlePlayerConnect');
		$parsed = parse_url($this->maniaControl->settingManager->getSetting($this, self::SETTING_LOGO_URL));
		if (!isset($parsed['path'])){
			$this->maniaControl->chat->sendInformation('Could not identify an image from the given URL, please adjust in the settings', null, false);
			return;
		}
		$pad = pathinfo($parsed['path']);
		$this->logodetails['name'] = $pad['basename'];
		$this->logodetails['url'] = $parsed['scheme'].'://'.$parsed['host'].'/'.$pad['dirname'].'/';
		$this->maniaControl->manialinkManager->iconManager->addIcon($this->logodetails['name'],$this->logodetails['url']);
		$this->displayLogoWidget();
		return true;
	}
	/**
	 * @see \ManiaControl\Plugins\Plugin::unload()
	 */
	public function unload() {
		$this->maniaControl->manialinkManager->hideManialink(self::MLID_LOGO);
	}
		

	
	public function displayLogoWidget($login=false) {
		$logo=$this->maniaControl->settingManager->getSetting($this, self::SETTING_LOGO_IMG_URL);
		//$logo=$this->maniaControl->manialinkManager->iconManager->getIcon($this->logodetails['name']);
		$url=$this->maniaControl->settingManager->getSetting($this, self::SETTING_LOGO_URL);
		$x=$this->maniaControl->settingManager->getSetting($this, self::SETTING_LOGO_POSX);
		$y=$this->maniaControl->settingManager->getSetting($this, self::SETTING_LOGO_POSY);
		$sizex=$this->maniaControl->settingManager->getSetting($this, self::SETTING_LOGO_SIZEX);
		$sizey=$this->maniaControl->settingManager->getSetting($this, self::SETTING_LOGO_SIZEY);
		$maniaLink = new ManiaLink(self::MLID_LOGO);
		$frame = new Frame();
		$maniaLink->add($frame);
		$frame->setSize($sizex,$sizey);
		$frame->setPosition($x, $y);
		$backgroundQuad = new Quad();
		$frame->add($backgroundQuad);
		$backgroundQuad->setSize($sizex,$sizey);
		$backgroundQuad->setImage($logo);
		$backgroundQuad->setUrl($url);
		$this->maniaControl->manialinkManager->sendManialink($maniaLink,$login);
	}	

	public function handlePlayerConnect(Player $player) {
		// Display Widget
		$this->displayLogoWidget($player->login);
	}
	/**
	 * @see \ManiaControl\Plugins\Plugin::getId()
	 */
	public static function getId() {
		return self::PLUGIN_ID;
	}

	/**
	 * @see \ManiaControl\Plugins\Plugin::getName()
	 */
	public static function getName() {
		return self::PLUGIN_NAME;
	}

	/**
	 * @see \ManiaControl\Plugins\Plugin::getVersion()
	 */
	public static function getVersion() {
		return self::PLUGIN_VERSION;
	}

	/**
	 * @see \ManiaControl\Plugins\Plugin::getAuthor()
	 */
	public static function getAuthor() {
		return self::PLUGIN_AUTHOR;
	}

	/**
	 * @see \ManiaControl\Plugins\Plugin::getDescription()
	 */
	public static function getDescription() {
		return 'Show your server logo during game,';
	}


}
